@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: Apache-2.0
 """SDNC package."""
-from .preload import VfModulePreload
+from .preload import NetworkPreload, VfModulePreload
